@@ -32,7 +32,7 @@ class EnviarPedido(Enviar):
     def sandbox(self):
         return "sandbox." if (settings.ENVIRONMENT == "local" or settings.ENVIRONMENT == "development") else ""
 
-    def gerar_dados_de_envio(self):
+    def gerar_dados_de_envio(self, passo=None):
         notification_url = settings.PAYPAL_NOTIFICATION_URL.format(self.pedido.conta_id)
         parametros = ParametrosPayPal("paypal", id=self.pedido.conta_id)
         express_checkout = ExpressCheckout(
